/*
 * libexplain - Explain errno values returned by libc functions
 * Copyright (C) 2010 Peter Miller
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <libexplain/ac/errno.h>
#include <libexplain/ac/sys/time.h>

#include <libexplain/adjtime.h>
#include <libexplain/option.h>
#include <libexplain/output.h>


int
explain_adjtime_on_error(const struct timeval *delta, struct timeval *olddelta)
{
    int             result;

    /* We have to cast away const-ness because Solaris is broken. */
    result = adjtime((struct timeval *)delta, olddelta);
    if (result < 0)
    {
        int             hold_errno;

        hold_errno = errno;
        explain_program_name_assemble_internal(1);
        explain_output_message
        (
            explain_errno_adjtime(hold_errno, delta, olddelta)
        );
        errno = hold_errno;
    }
    return result;
}


/* vim: set ts=8 sw=4 et */
